@@ -1,3 +1,20 @@
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-common.
+#
+# logilab-common is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option) any
+# later version.
+#
+# logilab-common is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """Classes to handle advanced configuration in simple to complex applications.
 
 Allows to load the configuration from a file or from command line
@@ -82,9 +99,9 @@ Quick start: simplest usage
   >>>
 
 
-:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
+
+
+
 """
 __docformat__ = "restructuredtext en"
 
@@ -464,8 +481,8 @@ class OptionsManagerMixIn(object):
 
     def add_optik_option(self, provider, optikcontainer, opt, optdict):
         if 'inputlevel' in optdict:
-            warn('"inputlevel" in option dictionary is deprecated, use "level"',
-                 DeprecationWarning)
+            warn('"inputlevel" in option dictionary for %s is deprecated, use'
+                 '"level"' % opt, DeprecationWarning)
             optdict['level'] = optdict.pop('inputlevel')
         args, optdict = self.optik_option(provider, opt, optdict)
         option = optikcontainer.add_option(*args, **optdict)
@@ -713,7 +730,7 @@ class OptionsManagerMixIn(object):
     @property
     def _config_parser(self):
         msg ='"_config_parser" attribute has been renamed to "cfgfile_parser"'
-        warn(msg, DeprecationWarning)
+        warn(msg, DeprecationWarning, stacklevel=2)
         return self.cfgfile_parser
 
 
