@@ -1,8 +1,25 @@
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-common.
+#
+# logilab-common is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option) any
+# later version.
+#
+# logilab-common is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """Date manipulation helper functions.
 
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: General Public License version 2 - http://www.gnu.org/licenses
+
+
+
 """
 __docformat__ = "restructuredtext en"
 
@@ -16,7 +33,7 @@ try:
     from mx.DateTime import RelativeDateTime, Date, DateTimeType
 except ImportError:
     from warnings import warn
-    warn("mxDateTime not found, endsOfMonth won't be available")
+    warn("mxDateTime not found, endOfMonth won't be available")
     endOfMonth = None
     DateTimeType = datetime
 else:
@@ -162,7 +179,7 @@ def date_range(begin, end, incday=None, incmonth=None):
                     date as parameter, and returning True if the date
                     should be included.
 
-    When using mx datetime, you should *NOT* use incmonth argument, use insteazd
+    When using mx datetime, you should *NOT* use incmonth argument, use instead
     oneDay, oneHour, oneMinute, oneSecond, oneWeek or endOfMonth (to enumerate
     months) as `incday` argument
     """
