@@ -1,10 +1,27 @@
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-common.
+#
+# logilab-common is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option) any
+# later version.
+#
+# logilab-common is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """Graph manipulation utilities.
 
 (dot generation adapted from pypy/translator/tool/make_dot.py)
 
-:copyright: 2000-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: General Public License version 2 - http://www.gnu.org/licenses
+
+
+
 """
 __docformat__ = "restructuredtext en"
 
@@ -62,7 +79,7 @@ class DotBackend:
 
     source = property(get_source)
 
-    def generate(self, outputfile=None, dotfile=None):
+    def generate(self, outputfile=None, dotfile=None, mapfile=None):
         """Generates a graph file.
 
         :param outputfile: filename and path [defaults to graphname.png]
@@ -98,7 +115,11 @@ class DotBackend:
             pdot.write(self.source)
         pdot.close()
         if target != 'dot':
-            subprocess.call('%s -T%s %s -o%s' % (self.renderer, target,
+            if mapfile:
+                subprocess.call('%s -Tcmapx -o%s -T%s %s -o%s' % (self.renderer, mapfile,
+                           target, dot_sourcepath, outputfile), shell=True)
+            else:
+                subprocess.call('%s -T%s %s -o%s' % (self.renderer, target,
                             dot_sourcepath, outputfile), shell=True)
             os.unlink(dot_sourcepath)
         return outputfile
@@ -131,7 +152,7 @@ class GraphGenerator:
         # the backend is responsible to output the graph in a particular format
         self.backend = backend
 
-    def generate(self, visitor, propshdlr, outputfile=None):
+    def generate(self, visitor, propshdlr, outputfile=None, mapfile=None):
         # the visitor
         # the property handler is used to get node and edge properties
         # according to the graph and to the backend
@@ -142,7 +163,41 @@ class GraphGenerator:
         for subjnode, objnode, edge in visitor.edges():
             props = propshdlr.edge_properties(edge, subjnode, objnode)
             self.backend.emit_edge(subjnode, objnode, **props)
-        return self.backend.generate(outputfile)
+        return self.backend.generate(outputfile=outputfile, mapfile=mapfile)
+
+
+class UnorderableGraph(Exception):
+    def __init__(self, cycles):
+        self.cycles = cycles
+
+    def __str__(self):
+        return 'cycles in graph: %s' % self.cycles
+
+def ordered_nodes(graph):
+    """takes a dependency graph dict as arguments and return an ordered tuple of
+    nodes starting with nodes without dependencies and up to the outermost node.
+
+    If there is some cycle in the graph, :exc:`UnorderableGraph` will be raised.
+
+    Also the given graph dict will be emptied.
+    """
+    cycles = get_cycles(graph)
+    if cycles:
+        cycles = '\n'.join(' -> '.join(cycle) for cycle in cycles)
+        raise UnorderableGraph(cycles)
+    ordered = []
+    while graph:
+        # sorted to get predictable results
+        for node, deps in sorted(graph.items()):
+            if not deps:
+                ordered.append(node)
+                del graph[node]
+                for deps in graph.itervalues():
+                    try:
+                        deps.remove(node)
+                    except KeyError:
+                        continue
+    return tuple(reversed(ordered))
 
 
 
