@@ -1,3 +1,20 @@
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-common.
+#
+# logilab-common is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option) any
+# later version.
+#
+# logilab-common is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """Add an abstraction level to transparently import optik classes from optparse
 (python >= 2.3) or the optik package.
 
@@ -28,10 +45,6 @@ It also defines three new types for optik/optparse command line parser :
   * bytes
     argument of this type will be converted to a float value in bytes
     according to byte units (b, kb, mb, gb, tb)
-
-:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
 """
 __docformat__ = "restructuredtext en"
 
@@ -261,7 +274,7 @@ def format_option_help(self, formatter):
     result = []
     outputlevel = getattr(formatter, 'output_level', 0)
     for option in self.option_list:
-        if option.level <= outputlevel and not option.help is SUPPRESS_HELP:
+        if getattr(option, 'level', 0) <= outputlevel and not option.help is SUPPRESS_HELP:
             result.append(formatter.format_option(option))
     return "".join(result)
 OptionContainer.format_option_help = format_option_help
@@ -347,20 +360,6 @@ class ManHelpFormatter(HelpFormatter):
 .SH COPYRIGHT
 %s
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published
-by the Free Software Foundation; either version 2 of the License,
-or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-MA 02111-1307 USA.
 .SH BUGS
 Please report bugs on the project\'s mailing list:
 %s
